%
% About:
%   This script is part of the supplementary material for the manuscript
%   entitled "Efficient bulk mass accommodation and dissociation
%   of N2O5 in neutral aqueous aerosol", submitted to Atmospheric Chemistry and Physics,
%   (Grinic et al., 2017).
%
%
function c_dot=ode_N2O5_13N_aq_01(t,c)
% NNO5 --> NO2+ + NO3-        k(1)
% N*NO5 --> N*O2+ + NO3-      k(1)/2  total decay of N*NO5 must remain k(1)
% N*NO5 --> NO2+ + N*O3-      k(1)/2  at each decay 50% chance for each
% NO2+ + NO3- --> NNO5        k(2)
% N*O2+ + NO3- --> N*NO5      k(2)
% NO2+ + N*O3- --> N*NO5      k(2)
% NO2+ + H2O --> NO3- + 2H+   k(3)
% N*O2+ + H2O --> N*O3- + 2H+ k(3)
% NNO5g --> NNO5  (g-->aq)    k(4)(aq), k(5)(g)
% N*NO5g --> N*NO5  (g-->aq)   k(4)(aq), k(5)(g)
% NNO5 --> NNO5g  (aq-->g)    k(6)(aq), k(7)(g)
% N*NO5 --> N*NO5g  (aq-->g)  k(6)(aq), k(7)(g)

% c(1)=NNO5,c(2)=N*NO5,c(3)=NO2+,c(4)=N*O2+,c(5)=NO3-,c(6)=N*O3-,
% c(7)=H2O,c(8)=H+,c(9)=NNO5g, c(10)=N*NO5g
% 

global k

c_dot(1,1)=-k(1)*c(1)+k(2)*c(3)*c(5)+k(4)*c(9)-k(6)*c(1); % d/dt [NNO5]
c_dot(2,1)=-2*(k(1)/2)*c(2)+k(2)*c(4)*c(5)+k(2)*c(3)*c(6)+k(4)*c(10)-k(6)*c(2); % d/dt [N*NO5]
c_dot(3,1)=k(1)*c(1)+(k(1)/2)*c(2)-k(2)*c(3)*c(5)-k(2)*c(3)*c(6)-k(3)*c(3)*c(7); % d/dt [NO2+]
c_dot(4,1)=(k(1)/2)*c(2)-k(2)*c(4)*c(5)-k(3)*c(4)*c(7); % d/dt [N*O2+]
c_dot(5,1)=k(1)*c(1)+(k(1)/2)*c(2)-k(2)*c(3)*c(5)-k(2)*c(4)*c(5)+k(3)*c(3)*c(7); % d/dt [NO3-]
c_dot(6,1)=(k(1)/2)*c(2)-k(2)*c(3)*c(6)+k(3)*c(4)*c(7); % d/dt [N*O3-]
c_dot(7,1)=-k(3)*c(3)*c(7)-k(3)*c(4)*c(7); % d/dt [H2O]
c_dot(8,1)=2*k(3)*c(3)*c(7)+2*k(3)*c(4)*c(7); % d/dt [H+]
c_dot(9,1)=-k(5)*c(9)+k(7)*c(1); % d/dt [NNO5g]
c_dot(10,1)=-k(5)*c(10)+k(7)*c(2); % d/dt [N*NO5g]

end